@@ -29,8 +29,10 @@ import logging
 
 import numpy as np
 
-from pymatgen.util.io_utils import zopen, clean_lines, micro_pyawk, clean_json
-from pymatgen.core.structure import Structure, Composition
+from pymatgen.util.io_utils import zopen, clean_lines, micro_pyawk, \
+    clean_json, reverse_readline
+from pymatgen.core.structure import Structure
+from pymatgen.core.composition import Composition
 from pymatgen.electronic_structure.core import Spin, Orbital
 from pymatgen.electronic_structure.dos import CompleteDos, Dos
 from pymatgen.electronic_structure.bandstructure import BandStructure, \
@@ -142,9 +144,8 @@ class Vasprun(object):
                             "ionic_steps", "dos_has_errors",
                             "projected_eigenvalues"]
 
-    def __init__(self, filename, ionic_step_skip=None,
-                 parse_dos=True, parse_eigen=True,
-                 parse_projected_eigen=False):
+    def __init__(self, filename, ionic_step_skip=None, parse_dos=True,
+                 parse_eigen=True, parse_projected_eigen=False):
         """
         Args:
             filename:
@@ -325,7 +326,7 @@ class Vasprun(object):
                                       "non-self-consistent (ICHARG=11) if not "
                                       "hybrid")
 
-        if efermi == None:
+        if efermi is None:
             efermi = self.efermi
 
         kpoint_file = Kpoints.from_file(kpoints_filename)
@@ -339,7 +340,6 @@ class Vasprun(object):
         if 'projected_eigenvalues' in self.to_dict['output']:
             dict_p_eigen = self.to_dict['output']['projected_eigenvalues']
 
-        eigenvals = {}
         p_eigenvals = {}
         if "up" in dict_eigen["1"] and "down" in dict_eigen["1"]\
                 and self.incar['ISPIN'] == 2:
@@ -353,7 +353,6 @@ class Vasprun(object):
 
         neigenvalues = [len(v['up']) for v in dict_eigen.values()]
         min_eigenvalues = min(neigenvalues)
-
         for i in range(min_eigenvalues):
             eigenvals[Spin.up].append([dict_eigen[str(j)]['up'][i][0]
                                        for j in range(len(kpoints))])
@@ -379,14 +378,14 @@ class Vasprun(object):
         #for this we look at the presence of the LHFCALC tag and of k-points
         #that have weights=0.0
         hybrid_band = False
-        if self.parameters['LHFCALC'] == True:
+        if self.parameters['LHFCALC']:
             for l in kpoint_file.labels:
                 if l != None:
                     hybrid_band = True
 
-        if kpoint_file.style == "Line_mode" or hybrid_band == True:
+        if kpoint_file.style == "Line_mode" or hybrid_band:
             labels_dict = {}
-            if hybrid_band == True:
+            if hybrid_band:
                 start_bs_index = 0
                 for i in range(len(self.actual_kpoints)):
                     if self.actual_kpoints_weights[i] == 0.0:
@@ -440,17 +439,16 @@ class Vasprun(object):
                 elif occu <= 1e-8 and eigenval < cbm:
                     cbm = eigenval
                     cbm_kpoint = k[0]
-        return (cbm - vbm, cbm, vbm, vbm_kpoint == cbm_kpoint)
+        return cbm - vbm, cbm, vbm, vbm_kpoint == cbm_kpoint
 
     @property
     def to_dict(self):
         """
         Json-serializable dict representation.
         """
-        d = {}
-        d["vasp_version"] = self.vasp_version
-        d["has_vasp_completed"] = self.converged
-        d["nsites"] = len(self.final_structure)
+        d = {"vasp_version": self.vasp_version,
+             "has_vasp_completed": self.converged,
+             "nsites": len(self.final_structure)}
         comp = self.final_structure.composition
         d["unit_cell_formula"] = comp.to_dict
         d["reduced_cell_formula"] = Composition(comp.reduced_formula).to_dict
@@ -499,17 +497,38 @@ class Vasprun(object):
             len(self.final_structure)
         vasp_output["crystal"] = self.final_structure.to_dict
         vasp_output["efermi"] = self.efermi
-        vasp_output["eigenvalues"] = {}
+        vasp_output['eigenvalues'] = {}
         for (spin, index), values in self.eigenvalues.items():
-            if str(index) not in vasp_output["eigenvalues"]:
-                vasp_output["eigenvalues"][str(index)] = {str(spin): values}
+            if index not in vasp_output['eigenvalues']:
+                vasp_output['eigenvalues'][index] = {str(spin): values}
             else:
-                vasp_output["eigenvalues"][str(index)][str(spin)] = values
+                vasp_output['eigenvalues'][index][str(spin)] = values
+
+        vasp_output['projected_eigenvalues'] = []
+        if len(self.projected_eigenvalues) != 0:
+            for i in range(len(vasp_output['eigenvalues'])):
+                vasp_output['projected_eigenvalues'].append({})
+                for spin in vasp_output['eigenvalues'][i]:
+                    vasp_output['projected_eigenvalues'][i][spin] = []
+                    for j in range(len(vasp_output['eigenvalues'][i][spin])):
+                        vasp_output['projected_eigenvalues'][i][spin].append(
+                                                                        {})
+            for (spin, kpoint_index, band_index, ion_index, orbital), value \
+                in self.projected_eigenvalues.items():
+                if orbital not in vasp_output['projected_eigenvalues'][
+                            kpoint_index][str(spin)][band_index]:
+                    vasp_output['projected_eigenvalues'][kpoint_index][
+                    str(spin)][band_index][orbital] = [0.0
+                    for s in range(len(self.final_structure.sites))]
+
+                else:
+                    vasp_output['projected_eigenvalues'][kpoint_index][
+                    str(spin)][band_index][orbital][ion_index] = value
 
         (gap, cbm, vbm, is_direct) = self.eigenvalue_band_properties
         vasp_output.update(dict(bandgap=gap, cbm=cbm, vbm=vbm,
-                                is_gap_direct=is_direct))
-        d["output"] = vasp_output
+                         is_gap_direct=is_direct))
+        d['output'] = vasp_output
 
         return clean_json(d, strict=True)
 
@@ -1048,8 +1067,7 @@ class Outcar(object):
         self.filename = filename
         self.is_stopped = False
         with zopen(filename, "r") as f:
-            read_charge = False
-            read_mag = False
+            read_charge_mag = False
             charge = []
             mag = []
             header = []
@@ -1058,71 +1076,61 @@ class Outcar(object):
             nelect = None
             efermi = None
 
-            # Only check the last 10,000 lines for content
-            # AJ has examples of OUTCARs with 23 million lines!!
-            # They take forever to parse and kill machines
-            MAX_LINES = 10000
-            SIZE_CUTOFF = 10000000  # 10MB
-            line_cutoff = 0
-            if os.path.getsize(filename) > SIZE_CUTOFF:
-                line_count = 0
-                for line in f:
-                    line_count += 1
-                line_cutoff = line_count - MAX_LINES
-                #rewind the file
-                f.seek(0)
-
             time_patt = re.compile("\((sec|kb)\)")
             efermi_patt = re.compile("E-fermi\s*:\s*(\S+)")
             nelect_patt = re.compile("number of electron\s+(\S+)\s+"
                                      "magnetization\s+(\S+)")
-
-            for idx, line in enumerate(f):
-                if idx >= line_cutoff:
-                    clean = line.strip()
-                    if clean == "total charge":
-                        read_charge = True
-                        charge = []
+            all_lines = []
+            for line in reverse_readline(f):
+                clean = line.strip()
+                all_lines.append(clean)
+                if clean.startswith("tot ") and not (charge and mag):
+                    read_charge_mag = True
+                    data = []
+                elif read_charge_mag:
+                    if clean.startswith("# of ion"):
+                        header = re.split("\s{2,}", line.strip())
+                        header.pop(0)
+                    elif clean == "total charge":
+                        data.reverse()
+                        charge = [dict(zip(header, v)) for v in data]
+                        read_charge_mag = False
                     elif clean == "magnetization (x)":
-                        read_mag = True
-                        mag = []
-                    elif read_charge or read_mag:
-                        if clean.startswith("# of ion"):
-                            header = re.split("\s{2,}", line.strip())
-                        elif clean.startswith("tot"):
-                            read_charge = False
-                            read_mag = False
-                        else:
-                            m = re.match("\s*(\d+)\s+(([\d\.\-]+)\s+)+", clean)
-                            if m:
-                                to_append = charge if read_charge else mag
-                                data = re.findall("[\d\.\-]+", clean)
-                                to_append.append({header[i]: float(data[i])
-                                                  for i
-                                                  in xrange(1, len(header))})
-                    elif line.find("soft stop encountered!  aborting job") \
-                            != -1:
-                        self.is_stopped = True
+                        data.reverse()
+                        mag = [dict(zip(header, v)) for v in data]
+                        read_charge_mag = False
                     else:
-                        if time_patt.search(line):
-                            tok = line.strip().split(":")
-                            run_stats[tok[0].strip()] = float(tok[1].strip())
+                        m = re.match("\s*(\d+)\s+(([\d\.\-]+)\s+)+", clean)
+                        if m:
+                            toks = [float(i) for i in re.findall("[\d\.\-]+",
+                                                                 clean)]
+                            toks.pop(0)
+                            data.append(toks)
+                elif clean.find("soft stop encountered!  aborting job") != -1:
+                    self.is_stopped = True
+                else:
+                    if time_patt.search(line):
+                        tok = line.strip().split(":")
+                        run_stats[tok[0].strip()] = float(tok[1].strip())
+                        continue
+                    m = efermi_patt.search(clean)
+                    if m:
+                        try:
+                            #try-catch because VASP sometimes prints
+                            #'E-fermi: ********     XC(G=0):  -6.1327
+                            #alpha+bet : -1.8238'
+                            efermi = float(m.group(1))
                             continue
-                        m = efermi_patt.search(clean)
-                        if m:
-                            try:
-                                #try-catch because VASP sometimes prints
-                                #'E-fermi: ********     XC(G=0):  -6.1327
-                                #alpha+bet : -1.8238'
-                                efermi = float(m.group(1))
-                                continue
-                            except:
-                                efermi = 0
-                                continue
-                        m = nelect_patt.search(clean)
-                        if m:
-                            nelect = float(m.group(1))
-                            total_mag = float(m.group(2))
+                        except:
+                            efermi = None
+                            continue
+                    m = nelect_patt.search(clean)
+                    if m:
+                        nelect = float(m.group(1))
+                        total_mag = float(m.group(2))
+                if all([nelect, total_mag is not None, efermi is not None,
+                        run_stats]):
+                    break
 
             self.run_stats = run_stats
             self.magnetization = tuple(mag)
@@ -1387,16 +1395,11 @@ class Outcar(object):
 
     @property
     def to_dict(self):
-        d = {}
-        d["@module"] = self.__class__.__module__
-        d["@class"] = self.__class__.__name__
-        d["efermi"] = self.efermi
-        d["run_stats"] = self.run_stats
-        d["magnetization"] = self.magnetization
-        d["charge"] = self.charge
-        d["total_magnetization"] = self.total_mag
-        d["nelect"] = self.nelect
-        d["is_stopped"] = self.is_stopped
+        d = {"@module": self.__class__.__module__,
+             "@class": self.__class__.__name__, "efermi": self.efermi,
+             "run_stats": self.run_stats, "magnetization": self.magnetization,
+             "charge": self.charge, "total_magnetization": self.total_mag,
+             "nelect": self.nelect, "is_stopped": self.is_stopped}
         return d
 
 
@@ -1569,7 +1572,7 @@ class VolumetricData(object):
                 data = {"total": all_dataset[0], "diff": all_dataset[1]}
             else:
                 data = {"total": all_dataset[0]}
-            return (poscar, data)
+            return poscar, data
 
     def write_file(self, file_name, vasp4_compatible=False):
         """
@@ -1894,7 +1897,8 @@ class VaspParserError(Exception):
         return "VaspParserError : " + self.msg
 
 
-def get_band_structure_from_vasp_multiple_branches(dir_name, efermi=None):
+def get_band_structure_from_vasp_multiple_branches(dir_name, efermi=None,
+                                            structure=None, projections=False):
     """
     this method is used to get band structure info from a VASP directory. It
     takes into account that the run can be divided in several branches named
@@ -1908,9 +1912,12 @@ def get_band_structure_from_vasp_multiple_branches(dir_name, efermi=None):
             Directory containing all bandstructure runs.
         efermi:
             Efermi for bandstructure.
+        projections:
+            True if you want to get the data on site projections if any
+            Note that this is sometimes very large
 
     Returns:
-        (bandstructure_up, bandstructure_down)
+        A BandStructure Object
     """
     #ToDo: Add better error handling!!!
     if os.path.exists(os.path.join(dir_name, "branch_0")):
@@ -1926,29 +1933,30 @@ def get_band_structure_from_vasp_multiple_branches(dir_name, efermi=None):
 
         # populate branches with Bandstructure instances
         branches = []
-
+        structure = None
         for dir_name in sorted_branch_dir_names:
             xml_file = os.path.join(dir_name, "vasprun.xml")
             if os.path.exists(xml_file):
-                run = Vasprun(xml_file)
+                run = Vasprun(xml_file, parse_projected_eigen=projections)
                 branches.append(run.get_band_structure(efermi=efermi))
+                structure = run.final_structure
             else:
                 # It might be better to throw an exception
                 warnings.warn("Skipping {}. Unable to find {}"
                               .format(d=dir_name, f=xml_file))
 
-        return get_reconstructed_band_structure(branches, efermi)
+        return get_reconstructed_band_structure(branches, efermi, structure)
     else:
         xml_file = os.path.join(dir_name, "vasprun.xml")
         #Better handling of Errors
         if os.path.exists(xml_file):
-            return Vasprun(xml_file).get_band_structure(kpoints_filename=None,
-                                                        efermi=efermi)
+            return Vasprun(xml_file, parse_projected_eigen=projections) \
+            .get_band_structure(kpoints_filename=None, efermi=efermi)
         else:
             return None
 
 
-def get_adjusted_fermi_level(run_static, band_structure):
+def get_adjusted_fermi_level(efermi, cbm, band_structure):
     """
     When running a band structure computations the fermi level needs to be
     take from the static run that gave the charge density used for the non-self
@@ -1962,8 +1970,10 @@ def get_adjusted_fermi_level(run_static, band_structure):
     level. This procedure has shown to detect correctly most insulators.
 
     Args:
-        run_static:
-            a Vasprun object for the static run
+        cbm:
+            the cbm of the static run
+        efermi:
+            the fermi energy of the static run
         run_bandstructure:
             a band_structure object
 
@@ -1973,10 +1983,10 @@ def get_adjusted_fermi_level(run_static, band_structure):
     #make a working copy of band_structure
     bs_working = BandStructureSymmLine.from_dict(band_structure.to_dict)
     if bs_working.is_metal():
-        e = run_static.efermi
-        while e < run_static.eigenvalue_band_properties[1]:
+        e = efermi
+        while e < cbm:
             e += 0.01
             bs_working._efermi = e
             if not bs_working.is_metal():
                 return e
-    return run_static.efermi
+    return efermi
