@@ -4,7 +4,7 @@
 This module provides utility classes for io operations.
 """
 
-__author__ = "Shyue Ping Ong, Rickard Armiento"
+__author__ = "Shyue Ping Ong, Rickard Armiento, Anubhav Jain"
 __copyright__ = "Copyright 2011, The Materials Project"
 __version__ = "1.0"
 __maintainer__ = "Shyue Ping Ong"
@@ -123,18 +123,18 @@ def micro_pyawk(filename, search, results=None, debug=None, postdebug=None):
         if isinstance(entry[0], str):
             entry[0] = re.compile(entry[0])
 
-    reader = zopen(filename)
-    for line in reader:
-        for i in range(len(search)):
-            match = search[i][0].search(line)
-            if match and (search[i][1] == None or search[i][1](results, line)):
-                if debug != None:
-                    debug(results, match)
-                search[i][2](results, match)
-                if postdebug != None:
-                    postdebug(results, match)
+    with zopen(filename) as f:
+        for line in f:
+            for i in range(len(search)):
+                match = search[i][0].search(line)
+                if match and (search[i][1] is not None
+                              or search[i][1](results, line)):
+                    if debug is not None:
+                        debug(results, match)
+                    search[i][2](results, match)
+                    if postdebug is not None:
+                        postdebug(results, match)
 
-    reader.close()
     return results
 
 
@@ -171,7 +171,7 @@ def clean_json(input_json, strict=False):
         else:
             if isinstance(input_json, basestring):
                 return str(input_json)
-            elif input_json == None:
+            elif input_json is None:
                 return 'None'
             else:
                 return clean_json(input_json.to_dict, strict=strict)
@@ -195,3 +195,52 @@ def which(program):
                 return exe_file
 
     return None
+
+
+def reverse_readline(m_file, blk_size=4096):
+    """
+    Generator method to read a file line-by-line, but backwards. This allows
+    one to efficiently get data at the end of a file.
+
+    Based on code by Peter Astrand <astrand@cendio.se>, using modifications by
+    Raymond Hettinger and Kevin German.
+    http://code.activestate.com/recipes/439045-read-a-text-file-backwards-yet-another-implementat/
+
+    Args:
+        m_file:
+            File stream to read (backwards)
+        blk_size:
+            The buffer size. Defaults to 4096.
+
+    Returns:
+        Generator that returns lines from the file. Similar behavior to the
+        file.readline() method, except the lines are returned from the back
+        of the file.
+    """
+
+    buf = ""
+    m_file.seek(0, 2)
+    lastchar = m_file.read(1)
+    trailing_newline = (lastchar == "\n")
+    
+    while 1:
+        newline_pos = buf.rfind("\n")
+        pos = m_file.tell()
+        if newline_pos != -1:
+            # Found a newline
+            line = buf[newline_pos+1:]
+            buf = buf[:newline_pos]
+            if pos or newline_pos or trailing_newline:
+                line += "\n"
+            yield line
+        elif pos:
+            # Need to fill buffer
+            toread = min(blk_size, pos)
+            m_file.seek(pos-toread, 0)
+            buf = m_file.read(toread) + buf
+            m_file.seek(pos-toread, 0)
+            if pos == toread:
+                buf = "\n" + buf
+        else:
+            # Start-of-file
+            return
